@@ -39,7 +39,7 @@ dropEmptyImageDimensions <- function(img,
                                      reorient = FALSE) {
   
   img = check_nifti(img, reorient = reorient, allow.array = FALSE)
-  if (dim_(img)[1] > 3){
+  if (dim_(img)[1] > 3) {
     stop(paste0("Only images with 3 dimensions supported, ", 
                 "as checked by dim_"))
   }    
@@ -47,62 +47,43 @@ dropEmptyImageDimensions <- function(img,
                                  value = value, 
                                  threshold = threshold,
                                  reorient = reorient)
-
-#   ############################
-#   # Set NAs to 0
-#   ############################
-#   arr = as.array(img)
-#   arr[is.na(arr)] = 0
-#   img = niftiarr(img, arr)
-#   
-#   
-#   ############################
-#   # Get indices for slices with all zeros (or of certain value)
-#   ############################
-#   inds = vector(mode = "list", length = 3)
-#   for (i in 1:3) {
-#     zero_x = apply(img, i, function(x) sum(x != value))
-#     dzero_x = !(
-#       cumsum(zero_x) <= threshold | 
-#         rev( cumsum(rev(zero_x)) <= threshold )
-#     )
-#     inds[[i]] = which(dzero_x)
-#     #     print(i)
-#   }
-  
-  ############################
-  # Get matrix of indices
-  ############################
-  all.inds = as.matrix(expand.grid(inds))
   
   ############################
   # Subset the image
   ############################
-  i2 = img[inds[[1]], inds[[2]], inds[[3]]]
-  
-  outimg = copyNIfTIHeader(img = img, arr = i2, drop = TRUE)
+  outimg = applyEmptyImageDimensions(img = img, 
+                                     inds = inds, 
+                                     reorient = reorient)
+  # i2 = img[inds[[1]], inds[[2]], inds[[3]]]
+  # 
+  # outimg = copyNIfTIHeader(img = img, arr = i2, drop = TRUE)
   
   if (!is.null(other.imgs)) {
-    if (is.nifti(other.imgs)) {
-      other.imgs = list(other.imgs)
-    }
-    stopifnot(is.list(other.imgs))
-    other.imgs = lapply(other.imgs, 
-                        check_nifti, reorient = reorient)
-    other.imgs = lapply(other.imgs, function(oimg){
-      i2 = oimg[inds[[1]], inds[[2]], inds[[3]]]
-      newimg = copyNIfTIHeader(img = img, arr = i2, drop = TRUE)
-      return(newimg)
-    })
-    if (length(other.imgs) == 1){
-      other.imgs = other.imgs[[1]]
-    }
+    other.imgs = applyEmptyImageDimensions(
+      other.imgs, 
+      inds = inds, reorient = reorient)
+    # if (is.nifti(other.imgs)) {
+    #   other.imgs = list(other.imgs)
+    # }
+    # stopifnot(is.list(other.imgs))
+    # other.imgs = lapply(other.imgs, 
+    #                     check_nifti, reorient = reorient)
+    # other.imgs = lapply(other.imgs, function(oimg){
+    #   i2 = oimg[inds[[1]], inds[[2]], inds[[3]]]
+    #   newimg = copyNIfTIHeader(img = img, arr = i2, drop = TRUE)
+    #   return(newimg)
+    # })
+    # if (length(other.imgs) == 1){
+    #   other.imgs = other.imgs[[1]]
+    # }
     return(list(outimg = outimg, 
                 other.imgs = other.imgs, 
-                inds = inds, orig.dim = dim(img)))
+                inds = inds, 
+                orig.dim = dim(img)))
   }
-  if (keep_ind){
-    outimg = list(outimg = outimg, inds = inds,
+  if (keep_ind) {
+    outimg = list(outimg = outimg, 
+                  inds = inds,
                   orig.dim = dim(img))
   }
   return(outimg)
